@@ -14,3 +14,12 @@ class VersionMismatchError(Exception):
     appropriately but the version installed is not sufficient.
     """
     pass
+
+
+class RequestsVersionTooOld(Warning):
+    """Used to indiciate that the Requests version is too old.
+
+    If the version of Requests is too old to support a feature, we will issue
+    this warning to the user.
+    """
+    pass
